==> nextcloud-14.0.13.zip: nextcloud/apps/gallery/l10n/cy_GB.js <==
OC.L10N.register(
    "gallery",
    {
    "Next" : "Nesaf",
    "Play" : "Chwarae",
    "Pause" : "Seibio",
    "Previous" : "Blaenorol",
    "Close" : "Cau",
    "Download" : "Llwytho i lawr",
    "Delete" : "Dileu",
    "Share" : "Rhannu",
    "File name cannot be empty." : "Does dim hawl cael enw ffeil gwag.",
    "Upload" : "Llwytho i fyny",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Error while changing permissions" : "Gwall wrth newid caniatâd",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "Password protect" : "Diogelu cyfrinair",
    "Password" : "Cyfrinair",
    "Email link to person" : "E-bostio dolen at berson",
    "Send" : "Anfon",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "group" : "grŵp",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "access control" : "rheolaeth mynediad",
    "create" : "creu",
    "delete" : "dileu",
    "Password protected" : "Diogelwyd â chyfrinair",
    "Error unsetting expiration date" : "Gwall wrth ddad-osod dyddiad dod i ben",
    "Error setting expiration date" : "Gwall wrth osod dyddiad dod i ben",
    "Email sent" : "Anfonwyd yr e-bost",
    "Warning" : "Rhybudd",
    "Cancel upload" : "Diddymu llwytho i fyny",
    "New" : "Newydd"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-17.0.6.zip: nextcloud/apps/gallery/l10n/cy_GB.js <==
OC.L10N.register(
    "gallery",
    {
    "Next" : "Nesaf",
    "Play" : "Chwarae",
    "Pause" : "Seibio",
    "Previous" : "Blaenorol",
    "Close" : "Cau",
    "Download" : "Llwytho i lawr",
    "Delete" : "Dileu",
    "Share" : "Rhannu",
    "File name cannot be empty." : "Does dim hawl cael enw ffeil gwag.",
    "Upload" : "Llwytho i fyny",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Error while changing permissions" : "Gwall wrth newid caniatâd",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "Share link" : "Rhannu dolen",
    "Link" : "Dolen",
    "Password protect" : "Diogelu cyfrinair",
    "Password" : "Cyfrinair",
    "Email link to person" : "E-bostio dolen at berson",
    "Send" : "Anfon",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "group" : "grŵp",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "access control" : "rheolaeth mynediad",
    "create" : "creu",
    "delete" : "dileu",
    "Password protected" : "Diogelwyd â chyfrinair",
    "Error unsetting expiration date" : "Gwall wrth ddad-osod dyddiad dod i ben",
    "Error setting expiration date" : "Gwall wrth osod dyddiad dod i ben",
    "Email sent" : "Anfonwyd yr e-bost",
    "Warning" : "Rhybudd",
    "Cancel upload" : "Diddymu llwytho i fyny",
    "Sort by name" : "Order by name",
    "Sort by date" : "Order by date"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
